#!/usr/bin/env python3

import sys
import math
from astropy.time import Time

DEG = math.pi/180.

def main():

    f = open("TLIST", "w")

    print("# JD (TDB; i.e. uncorrected for LITE) & separation rho [arcsec] & position angle theta [deg] & major [arcsec] & minor [arcsec] & PA [deg] of uncertainty ellipse & Besselian year & dataset");

    for line in sys.stdin:
        if line[0:1] == "#" or len(line) < 2:
            continue
        l = line.split()

#        jd = float(l[0])
        tisot = l[0] + "T" + l[1]
        x = float(l[2])
        y = float(l[3])
        dataset = "SPHERE2019"

        t1 = Time(tisot, format="isot", scale="utc")
        t2 = t1.tdb
        sep = math.sqrt(x**2+y**2)
        ang = math.atan2(x,y)
        if ang < 0.0:
            ang += 2.*math.pi
        PA_ellipse = 0.0
        sigma = 0.01
        major = sigma
        minor = sigma

        # lite = d/c * au/day
        lite = 0.0  # it's implemented in the code!
#        jd = jd - lite

        bessel = 1900.0 + (t1.jd - 2415020.31352) / 365.242198781

        print("%.8f	%.6f	%.6f	%.6f	%.6f	%.6f	%.6f	%s	#" % (t2.jd, sep, ang/DEG, major, minor, PA_ellipse, bessel, dataset))

        f.write("'%.8f'\n" % (t1.jd))

    f.close()

if __name__ == "__main__":
    main()


